@@ -1,4 +1,4 @@
-__conf = {
+__default_conf = {
     "irrep_normalization": "component",  # "component" or "norm"
     "path_normalization": "element",  # "element" or "path"
     "gradient_normalization": "path",  # "element", "path" or float,
@@ -10,6 +10,8 @@ __conf = {
     "sparse_tp": False,
 }
 
+__conf = __default_conf.copy()
+
 
 def config(name, value=None):
     if value is None:
